const Message = require('./schemas/message');

const getList = async (
	userId,
	{ sortBy, sortByDesc, filter, limit = '500', page = '1', sub }
) => {
	const options = { owner: userId };
	if (sub) options.subscription = { $all: [sub] };
	const results = await Message.paginate(options, {
		limit,
		page,
		sort: {
			...(sortBy ? { [`${sortBy}`]: 1 } : {}),
			...(sortByDesc ? { [`${sortByDesc}`]: -1 } : {}),
		},
		select: filter ? filter.split('|').join(' ') : '',
		populate: {
			path: 'owner',
			select: '_id',
		},
	});
	const { docs: messages, totalDocs: total } = results;
	return { total: total.toString(), limit, page, messages };
};

const getListById = async (companionId, userId) => {
	const messages = await Message.find({
		companionId,
		owner: userId,
	});
	return messages;
};

const getById = async (id, userId) => {
	const foundContact = await Message.findById({
		_id: id,
		owner: userId,
	});
	return foundContact;
};

const getByField = async (number, userId) => {
	const contact = await Message.findOne({
		number,
		owner: userId,
	});
	return contact;
};

const add = async (obj) => {
	const contact = await Message.create(obj);
	return contact;
};

const remove = async (id, userId) => {
	const removedContact = await Message.findByIdAndRemove({
		_id: id,
		owner: userId,
	});
	return removedContact;
};

module.exports = {
	getList,
	getListById,
	getByField,
	getById,
	add,
	remove,
};
